
# Type: gene to thing association_subject




URI: [biolink:gene_to_thing_association_subject](https://w3id.org/biolink/vocab/gene_to_thing_association_subject)


## Domain and Range

[GeneToThingAssociation](GeneToThingAssociation.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GeneToThingAssociation](GeneToThingAssociation.md)
